@@ -8,7 +8,7 @@ except NameError:
 
 def test_version():
   import dominate
-  version = '2.3.1'
+  version = '2.5.2'
   assert dominate.version == version
   assert dominate.__version__ == version
 
@@ -195,14 +195,25 @@ def test_attributes():
     del d['id']
   with pytest.raises(AttributeError):
     x = d['id']
-  with d:
+
+  with div() as d:
     attr(data_test=False)
-  assert d['data-test'] == 'false'
+  assert d['data-test'] is False
+
+  with div() as d:
+    attr(data_test=True)
+  assert d['data-test']
 
   with pytest.raises(ValueError):
     attr(id='moo')
 
 
+def test_attribute_dashes():
+  # fix issue #118 (https://github.com/Knio/dominate/issues/118)
+  expected = '<div aria-foo="bar" data-a-b-c="foo" data-page-size="123"></div>'
+  assert div(data_a_b_c='foo', data_page_size='123', aria_foo='bar').render() == expected
+
+
 def test_lazy():
   from dominate import util
   executed = [False]
@@ -227,12 +238,24 @@ def test_keyword_attributes():
   assert div(class_name='foo', html_for='bar').render() == expected
 
 
+def test_namespaced_attributes():
+  assert div(foo_bar='one').render() == '<div foo_bar="one"></div>'
+  assert div(xlink_href='one').render() == '<div xlink:href="one"></div>'
+
+
 def test_comment():
   d = comment('Hi there')
   assert d.render() == '<!--Hi there-->'
   assert div(d).render() == '<div>\n  <!--Hi there-->\n</div>'
 
 
+def test_boolean_attributes():
+  assert input_(type="checkbox", checked=True).render() == \
+      '<input checked="checked" type="checkbox">'
+  assert input_(type="checkbox", checked=False).render() == \
+      '<input type="checkbox">'
+
+
 def test_nested_decorator_2():
   @span
   def foo():
@@ -293,4 +316,3 @@ def test_xhtml():
 
   assert span('hi', br(), 'there').render(xhtml=False) == \
          '''<span>hi<br>there</span>'''
-
